@@ -1,4 +1,4 @@
-package Email::Sender::Role::CommonSending 2.500;
+package Email::Sender::Role::CommonSending 2.600;
 # ABSTRACT: the common sending tasks most Email::Sender classes will need
 
 use Moo::Role;
@@ -127,7 +127,7 @@ Email::Sender::Role::CommonSending - the common sending tasks most Email::Sender
 
 =head1 VERSION
 
-version 2.500
+version 2.600
 
 =head1 DESCRIPTION
 
@@ -182,11 +182,11 @@ a convenience for returning success from subclasses' C<send_email> methods.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
